# Venture

A Dmenu / Rofi / Wofi menu to open projects and files in your favorite editor!



### Dependancies
- Venture supports three UI providers: dmenu, rofi, and wofi. It is expected that you have the one you intend to use installed.

- Venture uses [Nerdfonts](https://www.nerdfonts.com/) for icons

## Installation

```
$ pip install venture
```

## Docs
[Here](./docs)

Note this may installing into `~/.local/bin` which is not part of the default path on some Linux systems